@@ -35,9 +35,12 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Node };
 
-use PPIx::Regexp::Constant qw{ MSG_PROHIBITED_BY_STRICT };
+use PPIx::Regexp::Constant qw{
+    MSG_PROHIBITED_BY_STRICT
+    @CARP_NOT
+};
 
-our $VERSION = '0.051';
+our $VERSION = '0.070';
 
 sub explain {
     my ( $self ) = @_;
@@ -112,7 +115,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -120,7 +123,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
