@@ -51,9 +51,9 @@ use warnings;
 use base qw{PPIx::Regexp::Element};
 
 use Carp qw{ confess };
-use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ MINIMUM_PERL @CARP_NOT };
 
-our $VERSION = '0.051';
+our $VERSION = '0.070';
 
 use constant TOKENIZER_ARGUMENT_REQUIRED => 0;
 
@@ -68,7 +68,9 @@ sub __new {
 	content => $content,
     };
 
-    foreach my $key ( qw{ perl_version_introduced } ) {
+    foreach my $key ( qw{
+	    explanation perl_version_introduced perl_version_removed
+	} ) {
 	defined $arg{$key}
 	    and $self->{$key} = $arg{$key};
     }
@@ -82,11 +84,38 @@ sub content {
     return $self->{content};
 }
 
+=head2 first_token
+
+This method returns its invocant.
+
+=cut
+
+sub first_token {
+    my ( $self ) = @_;
+    return $self;
+}
+
+=head2 last_token
+
+This method returns its invocant.
+
+=cut
+
+sub last_token {
+    my ( $self ) = @_;
+    return $self;
+}
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     return defined $self->{perl_version_introduced} ?
-    $self->{perl_version_introduced} :
-    MINIMUM_PERL;
+	$self->{perl_version_introduced} :
+	MINIMUM_PERL;
+}
+
+sub perl_version_removed {
+    my ( $self ) = @_;
+    return $self->{perl_version_removed};
 }
 
 sub unescaped_content {
@@ -96,6 +125,13 @@ sub unescaped_content {
     return $content;
 }
 
+sub scontent {
+    my ( $self ) = @_;
+    $self->significant()
+	and return $self->{content};
+    return;
+}
+
 # Called by the lexer once it has done its worst to all the tokens.
 # Called as a method with the lexer as argument. The return is the
 # number of parse failures discovered when finalizing.
@@ -110,7 +146,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -118,7 +154,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
