@@ -41,9 +41,14 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::CharClass };
 
-use PPIx::Regexp::Constant qw{ COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{
+    COOKIE_CLASS
+    COOKIE_REGEX_SET
+    MINIMUM_PERL
+    @CARP_NOT
+};
 
-our $VERSION = '0.051';
+our $VERSION = '0.070';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -74,19 +79,33 @@ sub perl_version_introduced {
 
     my %explanation = (
 	'[:alnum:]'	=> 'Any alphanumeric character',
-	'[:alpha:]'	=> 'Match alphabetic',
+	'[:^alnum:]'	=> 'Anything but an alphanumeric character',
+	'[:alpha:]'	=> 'Any alphabetic',
+	'[:^alpha:]'	=> 'Anything but an alphabetic',
 	'[:ascii:]'	=> 'Any character in the ASCII character set',
+	'[:^ascii:]'	=> 'Anything but a character in the ASCII character set',
 	'[:blank:]'	=> 'A GNU extension, equal to a space or a horizontal tab ("\\t")',
+	'[:^blank:]'	=> 'A GNU extension, anything but a space or a horizontal tab ("\\t")',
 	'[:cntrl:]'	=> 'Any control character',
-	'[:digit:]'	=> 'Any decimal digit ("[0-9]")',
-	'[:graph:]'	=> 'Any printable character, excluding a space',
+	'[:^cntrl:]'	=> 'Anything but a control character',
+	'[:digit:]'	=> 'Any decimal digit',
+	'[:^digit:]'	=> 'Anything but a decimal digit',
+	'[:graph:]'	=> 'Any non-space printable character',
+	'[:^graph:]'	=> 'Anything but a non-space printable character',
 	'[:lower:]'	=> 'Any lowercase character',
+	'[:^lower:]'	=> 'Anything but a lowercase character',
 	'[:print:]'	=> 'Any printable character',
+	'[:^print:]'	=> 'Anything but a printable character',
 	'[:punct:]'	=> 'Any graphical character excluding "word" characters',
+	'[:^punct:]'	=> 'Anything but a graphical character excluding "word" characters',
 	'[:space:]'	=> 'Any whitespace character',
+	'[:^space:]'	=> 'Anything but a whitespace character',
 	'[:upper:]'	=> 'Any uppercase character',
+	'[:^upper:]'	=> 'Anything but an uppercase character',
 	'[:word:]'	=> 'A Perl extension, equivalent to "\\w"',
+	'[:^word:]'	=> 'A Perl extension, equivalent to "\\W"',
 	'[:xdigit:]'	=> 'Any hexadecimal digit',
+	'[:^xdigit:]'	=> 'Anything but a hexadecimal digit',
     );
 
     sub __explanation {
@@ -94,9 +113,12 @@ sub perl_version_introduced {
     }
 
     sub __no_explanation {
-##	my ( $self ) = @_;		# Invocant unused
-	my $msg = sprintf q<Unknown POSIX character class>;
-	return $msg;
+	my ( $self ) = @_;
+	local $_ = $self->content();
+	m/ \A \[ = ( . ) = \] \z /smx
+	    and return "POSIX Character Equivalent (to '$1'; " .
+		"unimplemented in Perl)";
+	return q<Unknown POSIX character class>;
     }
 
 }
@@ -134,7 +156,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -142,7 +164,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
