@@ -34,30 +34,23 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.051';
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-# Return true if the token can be quantified, and false otherwise
-# sub can_be_quantified { return };
+our $VERSION = '0.070';
 
 {
-
-    my %explanation = (
-	'?>'	=> 'Match subexpression without backtracking',
+    my $expl = 'Match subexpression without backtracking';
+    __PACKAGE__->__setup_class( {
+	    '?>'		=> {
+		expl	=> $expl,
+		intro	=> '5.005',
+	    },
+	    '*atomic:'	=> {
+		expl	=> $expl,
+		intro 	=>'5.027009',
+	    },
+	}
     );
-
-    sub __explanation {
-	return \%explanation;
-    }
-
-}
-
-sub perl_version_introduced {
-##  my ( $self ) = @_;		# Invocant unused
-    return '5.005';
-}
-
-sub __defining_string {
-    return '?>';
 }
 
 1;
@@ -67,7 +60,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -75,7 +68,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
