@@ -8,17 +8,26 @@ use warnings;
 use base qw{ PPIx::Regexp::Token };
 
 use Carp;
-use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ MINIMUM_PERL @CARP_NOT };
 
-our $VERSION = '0.051';
+our $VERSION = '0.070';
 
-sub __new {
-    my ( $class, $content, %arg ) = @_;
+{
+    my %when_removed = (
+	'\\N{}'	=> '5.027001',
+    );
 
-    defined $arg{perl_version_introduced}
-	or $arg{perl_version_introduced} = MINIMUM_PERL;
+    sub __new {
+	my ( $class, $content, %arg ) = @_;
 
-    return $class->SUPER::__new( $content, %arg );
+	defined $arg{perl_version_introduced}
+	    or $arg{perl_version_introduced} = MINIMUM_PERL;
+
+	exists $arg{perl_version_removed}
+	    or $arg{perl_version_removed} = $when_removed{$content};
+
+	return $class->SUPER::__new( $content, %arg );
+    }
 }
 
 # Return true if the token can be quantified, and false otherwise
@@ -28,11 +37,6 @@ sub explain {
     return 'Not significant';
 }
 
-sub perl_version_introduced {
-    my ( $self ) = @_;
-    return $self->{perl_version_introduced};
-}
-
 sub significant {
     return;
 }
@@ -72,7 +76,7 @@ superclass.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -80,7 +84,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2017 by Thomas R. Wyant, III
+Copyright (C) 2016-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
